==> neo4j-kernel-4.4.10-sources.jar: org/neo4j/kernel/impl/transaction/stats/TransactionCounters.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.transaction.stats;

import org.neo4j.kernel.impl.api.transaction.monitor.TransactionSizeMonitor;

public interface TransactionCounters
{
    long getPeakConcurrentNumberOfTransactions();

    long getNumberOfStartedTransactions();

    long getNumberOfCommittedTransactions();

    long getNumberOfCommittedReadTransactions();

    long getNumberOfCommittedWriteTransactions();

    long getNumberOfActiveTransactions();

    long getNumberOfActiveReadTransactions();

    long getNumberOfActiveWriteTransactions();

    long getNumberOfTerminatedTransactions();

    long getNumberOfTerminatedReadTransactions();

    long getNumberOfTerminatedWriteTransactions();

    long getNumberOfRolledBackTransactions();

    long getNumberOfRolledBackReadTransactions();

    long getNumberOfRolledBackWriteTransactions();

    void setTransactionSizeCallback( TransactionSizeMonitor transactionSizeMonitor );
}

==> neo4j-kernel-5.3.0-sources.jar: org/neo4j/kernel/impl/transaction/stats/TransactionCounters.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.transaction.stats;

import org.neo4j.kernel.impl.api.transaction.monitor.TransactionSizeMonitor;

public interface TransactionCounters {
    long getPeakConcurrentNumberOfTransactions();

    long getNumberOfStartedTransactions();

    long getNumberOfCommittedTransactions();

    long getNumberOfCommittedReadTransactions();

    long getNumberOfCommittedWriteTransactions();

    long getNumberOfActiveTransactions();

    long getNumberOfActiveReadTransactions();

    long getNumberOfActiveWriteTransactions();

    long getNumberOfTerminatedTransactions();

    long getNumberOfTerminatedReadTransactions();

    long getNumberOfTerminatedWriteTransactions();

    long getNumberOfRolledBackTransactions();

    long getNumberOfRolledBackReadTransactions();

    long getNumberOfRolledBackWriteTransactions();

    void setTransactionSizeCallback(TransactionSizeMonitor transactionSizeMonitor);
}
